| get_complexity_empirical | R Documentation |
Get empirical split counts. This is a sub-routine of
get_complexity, which should typically be used instead.
get_complexity_empirical(model.dt,
min.segment.length = 1L)
model.dt |
splits data table from |
min.segment.length |
Minimum segment length, positive integer. |
data.table with one row per model size, and column splits with number of splits to check after computing that model size.
Toby Dylan Hocking
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.